@@ -364,7 +364,7 @@ setMethod('mapView', signature(x = 'sf'),
                    lwd = lineWidth(x),
                    alpha = 0.9,
                    alpha.regions = regionOpacity(x),
-                   na.alpha = NULL,
+                   na.alpha = alpha,
                    map.types = NULL,
                    verbose = mapviewGetOption("verbose"),
                    popup = popupTable(x),
@@ -678,8 +678,8 @@ setMethod('mapView', signature(x = 'list'),
                    na.color = mapviewGetOption("na.color"),
                    cex = 6,
                    lwd = lapply(x, lineWidth),
-                   alpha = 0.9,
-                   alpha.regions = 0.6,
+                   alpha = lapply(seq(x), function(i) 0.9),
+                   alpha.regions = lapply(seq(x), function(i) 0.6),
                    map.types = mapviewGetOption("basemaps"),
                    verbose = mapviewGetOption("verbose"),
                    popup = lapply(seq(x), function(i) {
@@ -696,8 +696,8 @@ setMethod('mapView', signature(x = 'list'),
                    native.crs = FALSE,
                    highlight = lapply(seq(x), function(i) {
                      mapviewHighlightOptions(x[[i]],
-                                             alpha.regions = alpha.regions,
-                                             alpha = alpha,
+                                             alpha.regions = alpha.regions[[i]],
+                                             alpha = alpha[[i]],
                                              lwd = lwd[[i]])
                    }),
                    maxpoints = NULL, #lapply(x, getMaxFeatures),
